==> gspiceui-v0.8.90.tar.gz: gspiceui-v0.8.90/src/gnucap/PnlGnuCapAC.cpp <==
//*****************************************************************************
//                               PnlGnuCapAC.cpp                              *
//                              -----------------                             *
//  Started     : 18/08/2003                                                  *
//  Last Update : 02/05/2006                                                  *
//  Copyright   : (C) 2003 by MSWaters                                        *
//  Email       : M.Waters@bom.gov.au                                         *
//*****************************************************************************

//*****************************************************************************
//                                                                            *
//    This program is free software; you can redistribute it and/or modify    *
//    it under the terms of the GNU General Public License as published by    *
//    the Free Software Foundation; either version 2 of the License, or       *
//    (at your option) any later version.                                     *
//                                                                            *
//*****************************************************************************

#include "gnucap/PnlGnuCapAC.hpp"

//*****************************************************************************
// Implement an event table.

BEGIN_EVENT_TABLE( PnlGnuCapAC, PnlAnaBase )

  EVT_RADIOBOX( ID_RBX_SCALE,   PnlGnuCapAC::OnScale   )
  EVT_CHOICE  ( ID_CHO_SRCCPNT, PnlGnuCapAC::OnSrcCpnt )

END_EVENT_TABLE( )

//*****************************************************************************
// Constructor.

PnlGnuCapAC::PnlGnuCapAC( wxWindow * poWin ) : PnlAnaBase( poWin )
{
  bSetSimrType( Simulation::eSIMR_GNUCAP );
  bSetAnaType( Simulation::eANA_AC );

  Create( );  // Create the analysis panel
  bClear( );  // Clear all object attributes
}

//*****************************************************************************
// Destructor.

PnlGnuCapAC::~PnlGnuCapAC( )
{
}

//*****************************************************************************
// Create the display objects.

void  PnlGnuCapAC::Create( void )
{
  int  ix, iy;

  // Set the frequency sweep parameter labels
  m_oSbxSwpPars.GetSize( &ix, &iy );
  m_oSbxSwpPars.SetSize(  ix, 167 );
  m_oSbxSwpPars.SetLabel( wxT("AC Sweep") );
  m_oPnlStart  .bSetName( wxT("Start Frequency") );
  m_oPnlStop   .bSetName( wxT("Stop Frequency") );

  // Set sweep parameter units
  m_oPnlStart.bSetUType( ChoUnits::eUNTS_FREQ );
  m_oPnlStop .bSetUType( ChoUnits::eUNTS_FREQ );
  m_oPnlStep .bSetUType( ChoUnits::eUNTS_FREQ );

  // Create and add the scale radio buttons
  wxString  osScale[4] = { wxT("Lin  "), wxT("Log"), wxT("Dec"), wxT("Oct ") };
  m_oRbxScale.Create( this, ID_RBX_SCALE, wxT("Step Scale"), wxPoint( 13, 123 ),
                      wxDefaultSize, 4, osScale, 4 );
  bSetScale( eSCALE_LIN );

  CreateCpxPrt( ); // Create the simulation parameter complex part check boxes
  CreateTemp( );   // Create the analysis temperature controls
  CreateSrc( );    // Create the input source controls
}

//*****************************************************************************
// Set the state of the step scale radio box.
//
// Argument List:
//   eScale - The enumerated scale specifier
//
// Return Values:
//   Success - TRUE
//   Failure - FALSE

bool  PnlGnuCapAC::bSetScale( eScaleType eScale )
{
  wxCommandEvent  oEvtCmd;

  if( eScale<eSCALE_FST || eScale>eSCALE_LST ) return( FALSE );
  if( m_oRbxScale.GetCount( ) < (eScale + 1) ) return( FALSE );

  m_oRbxScale.SetSelection( (int) eScale );

  OnScale( oEvtCmd );

  return( TRUE );
}

//*****************************************************************************
// Clear the object attributes.
//
// Return Values:
//   TRUE  - Success
//   FALSE - Failure

bool  PnlGnuCapAC::bClear( void )
{
  bool  bRtn=TRUE;

  // Clear the base class
  if( ! PnlAnaBase::bClear( ) )   bRtn = FALSE;
  m_oPnlStart.bSetValue( (float)  1.0 );
  m_oPnlStep .bSetValue( (float) 10.0 );

  // Set the default sweep units
  m_oPnlStart.bSetUnits( wxT("kHz") );
  m_oPnlStop .bSetUnits( wxT("kHz") );
  m_oPnlStep .bShowUnits( TRUE );
  m_oPnlStep .bSetUnits( wxT("kHz") );

  // Set default scale value
  if( ! bSetScale( eSCALE_DEC ) ) bRtn = FALSE;

  return( bRtn );
}

//*****************************************************************************
// Load information from a Simulation object.
//
// Argument List:
//   roSim - The Simulation object
//
// Return Values:
//   TRUE  - Success
//   FALSE - Failure

bool  PnlGnuCapAC::bLoad( Simulation & roSim )
{
  wxString  os1;
  bool  bRtn=TRUE;
  uint  ui1;

  m_oChoSrcCpnt.Clear( );
  m_oChoSrcCpnt.Append( wxT("None") );

  // Load the components into the choice box
  const wxArrayString & roasCpnts = roSim.roasGetCpntLbls( );
  for( ui1=0; ui1<roasCpnts.GetCount( ); ui1++ )
  {
    os1 = roasCpnts.Item( ui1 );
    if( os1.Length( ) <= 0 ) continue;
    switch( wxToupper( os1.GetChar( 0 ) ) )
    {
      case 'V':
      case 'I': break;
      default : continue;
    }
    m_oChoSrcCpnt.Append( os1 );
  }
  m_oChoSrcCpnt.SetStringSelection( wxT("None") );

  // Don't go any further if the analysis type doesn't match
  if( roSim.eGetAnaType( ) != eGetAnaType( ) ) return( TRUE );

  // Perform any base class load tasks
  if( ! PnlAnaBase::bLoad( roSim ) ) bRtn = FALSE;

  // Set the sweep scale
  m_oRbxScale.SetSelection( roSim.iGetSwpScale( ) );
  wxCommandEvent oEvtCmd;
  OnScale( oEvtCmd );

  return( bRtn );
}

//*****************************************************************************
// Reload information from a Simulation object.
//
// Argument List:
//   roSim - The Simulation object
//
// Return Values:
//   TRUE  - Success
//   FALSE - Failure

bool  PnlGnuCapAC::bReload( Simulation & roSim )
{
  wxCommandEvent  oEvtCmd;
  wxString  os1;
  double    df1;

  os1 = m_oChoSrcCpnt.GetStringSelection( );
  df1 = m_oPnlSrcLvl.dfGetValue( );

  if( ! bLoad( roSim ) ) return( FALSE );

  if( !os1.IsEmpty( ) && os1!=wxT("None") )
  {
    m_oChoSrcCpnt.SetStringSelection( os1 );
    OnSrcCpnt( oEvtCmd );
    m_oPnlSrcLvl.bSetValue( df1 );
  }

  return( TRUE );
}

//*****************************************************************************
// Save information to a Simulation object.
//
// Argument List:
//   roSim - The Simulation object
//
// Return Values:
//   TRUE  - Success
//   FALSE - Failure

bool  PnlGnuCapAC::bSave( Simulation & roSim )
{
  wxString  os1;
  float     f1;
  size_t    szt1;

  // Execute base class save tasks
  PnlAnaBase::bSave( roSim );

  // Check that the step size is valid
  if( m_oRbxScale.GetSelection( ) == 0 )
  {
    f1 = fabs( roSim.fGetSwpStop( ) - roSim.fGetSwpStart( ) );
    if( roSim.fGetSwpStep( ) > f1 )
      SetErrMsg( wxT("Step size is greater than sweep range.") );
  }

  // Set the sweep scale
  szt1 = m_oRbxScale.GetSelection( );
  if( ! roSim.bSetSwpScale( szt1 ) )
    SetErrMsg( wxT("Sweep scale couldn't be set.") );

  // Set the component to be used as the sweep source
  if( m_oPnlSrcLvl.dfGetValue( ) != 0.0 )
  {
    os1 = roSim.rosGetSrcCpnt( );
    szt1 = os1.Find( wxT(' '), TRUE );
    os1.insert( szt1, wxT(" GENERATOR(1) AC") );
    if( ! roSim.bSetSrcCpnt( os1 ) )
      SetErrMsg( wxT("Source component couldn't be set.") );
  }
  else SetErrMsg( wxT("Source component value of zero is not permitted.") );

  return( bIsOk( ) );
}

//*****************************************************************************
//                                                                            *
//                             Event Handlers                                 *
//                                                                            *
//*****************************************************************************
// Step scale radio box event handler.
//
// Argument List:
//   roEvtCmd - An object holding information about the event

void  PnlGnuCapAC::OnScale( wxCommandEvent & roEvtCmd )
{
  switch( m_oRbxScale.GetSelection( ) )
  {
    case eSCALE_LIN:
      m_oPnlStep.bSetName( wxT("Step Increment") );
      m_oPnlStep.bSetVType( SpinCtrl::eVAR_FLT );
      m_oPnlStep.bSetUType( ChoUnits::eUNTS_FREQ );
      m_oPnlStep.bShowUnits( TRUE );
      break;
    case eSCALE_LOG:
      m_oPnlStep.bSetName( wxT("Step Multiplier") );
      m_oPnlStep.bSetVType( SpinCtrl::eVAR_FLT );
      m_oPnlStep.bSetParms( 1.1, 0.01, 10.0, 1.0, 10.0 );
      m_oPnlStep.bShowUnits( FALSE );
      break;
    case eSCALE_DEC:
      m_oPnlStep.bSetName( wxT("Steps / Decade") );
      m_oPnlStep.bSetVType( SpinCtrl::eVAR_INT );
      m_oPnlStep.bSetParms( 10, 1, 10000, 1, 100 );
      m_oPnlStep.bShowUnits( FALSE );
      break;
    case eSCALE_OCT:
      m_oPnlStep.bSetName( wxT("Steps / Octave") );
      m_oPnlStep.bSetVType( SpinCtrl::eVAR_INT );
      m_oPnlStep.bSetParms( 10, 1, 10000, 1, 100 );
      m_oPnlStep.bShowUnits( FALSE );
      break;
    default:
      break;
  }
}

//*****************************************************************************
// Source component choice box event handler.
//
// Argument List:
//   roEvtCmd - An object holding information about the event

void  PnlGnuCapAC::OnSrcCpnt( wxCommandEvent & roEvtCmd )
{
  SetSrcUType( );

  if( m_oChoSrcCpnt.GetStringSelection( ) == wxT("None") )
    m_oPnlSrcLvl.bSetValue( (double) 0.0 );
  else if( m_oPnlSrcLvl.dfGetValue( ) == 0.0 )
    m_oPnlSrcLvl.bSetValue( (double) 1.0 );
}

//*****************************************************************************

==> gspiceui-v0.9.33.tar.gz: gspiceui-v0.9.33/src/gnucap/PnlGnuCapAC.cpp <==
//*****************************************************************************
//                               PnlGnuCapAC.cpp                              *
//                              -----------------                             *
//  Started     : 18/08/2003                                                  *
//  Last Update : 04/07/2007                                                  *
//  Copyright   : (C) 2003 by MSWaters                                        *
//  Email       : M.Waters@bom.gov.au                                         *
//*****************************************************************************

//*****************************************************************************
//                                                                            *
//    This program is free software; you can redistribute it and/or modify    *
//    it under the terms of the GNU General Public License as published by    *
//    the Free Software Foundation; either version 2 of the License, or       *
//    (at your option) any later version.                                     *
//                                                                            *
//*****************************************************************************

#include "gnucap/PnlGnuCapAC.hpp"

//*****************************************************************************
// Implement an event table.

BEGIN_EVENT_TABLE( PnlGnuCapAC, PnlAnaBase )

  EVT_RADIOBOX( ID_RBX_SCALE,   PnlGnuCapAC::OnScale   )
  EVT_CHOICE  ( ID_CHO_SRCCPNT, PnlGnuCapAC::OnSrcCpnt )

END_EVENT_TABLE( )

//*****************************************************************************
// Constructor.

PnlGnuCapAC::PnlGnuCapAC( wxWindow * poWin ) : PnlAnaBase( poWin )
{
  bSetSimrType( Simulation::eSIMR_GNUCAP );
  bSetAnaType( Simulation::eANA_AC );

  Create( );  // Create the analysis panel
  bClear( );  // Clear all object attributes
}

//*****************************************************************************
// Destructor.

PnlGnuCapAC::~PnlGnuCapAC( )
{
}

//*****************************************************************************
// Create the display objects.

void  PnlGnuCapAC::Create( void )
{
  int  ix, iy;

  // Set the frequency sweep parameter labels
  m_oSbxSwpPars.GetSize( &ix, &iy );
  m_oSbxSwpPars.SetSize(  ix, 167 );
  m_oSbxSwpPars.SetLabel( wxT(" AC Sweep ") );
  m_oPnlStart  .bSetName( wxT("Start Frequency") );
  m_oPnlStop   .bSetName( wxT("Stop Frequency") );

  // Set sweep parameter units
  m_oPnlStart.bSetUnitsType( ChoUnits::eUNITS_FREQ );
  m_oPnlStop .bSetUnitsType( ChoUnits::eUNITS_FREQ );
  m_oPnlStep .bSetUnitsType( ChoUnits::eUNITS_FREQ );

  // Create and add the scale radio buttons
  wxString  osScale[4] = { wxT("Lin  "), wxT("Log"), wxT("Dec"), wxT("Oct ") };
  m_oRbxScale.Create( this, ID_RBX_SCALE, wxT(" Step Scale "),
                      wxPoint( 13, 123 ), wxDefaultSize, 4, osScale, 4 );
  bSetScale( eSCALE_LIN );

  CreateCpxPrt( ); // Create the simulation parameter complex part check boxes
  CreateTemp( );   // Create the analysis temperature controls
  CreateSrc( );    // Create the input source controls
}

//*****************************************************************************
// Set the state of the step scale radio box.
//
// Argument List:
//   eScale - The enumerated scale specifier
//
// Return Values:
//   Success - TRUE
//   Failure - FALSE

bool  PnlGnuCapAC::bSetScale( eScaleType eScale )
{
  wxCommandEvent  oEvtCmd;

  if( eScale<eSCALE_FST || eScale>eSCALE_LST )        return( FALSE );
  if( m_oRbxScale.GetCount( ) < (uint) (eScale + 1) ) return( FALSE );

  m_oRbxScale.SetSelection( (int) eScale );

  OnScale( oEvtCmd );

  return( TRUE );
}

//*****************************************************************************
// Clear the object attributes.
//
// Return Values:
//   TRUE  - Success
//   FALSE - Failure

bool  PnlGnuCapAC::bClear( void )
{
  bool  bRtn=TRUE;

  // Clear the base class
  if( ! PnlAnaBase::bClear( ) )   bRtn = FALSE;
  m_oPnlStart.bSetValue( (float)  1.0 );
  m_oPnlStep .bSetValue( (float) 10.0 );

  // Set the default sweep units
  m_oPnlStart.bSetUnits( wxT("kHz") );
  m_oPnlStop .bSetUnits( wxT("kHz") );
  m_oPnlStep .bShowUnits( TRUE );
  m_oPnlStep .bSetUnits( wxT("kHz") );

  // Set default scale value
  if( ! bSetScale( eSCALE_DEC ) ) bRtn = FALSE;

  return( bRtn );
}

//*****************************************************************************
// Load information from a Simulation object.
//
// Argument List:
//   roSim - The Simulation object
//
// Return Values:
//   TRUE  - Success
//   FALSE - Failure

bool  PnlGnuCapAC::bLoad( Simulation & roSim )
{
  wxString  os1;
  bool  bRtn=TRUE;
  uint  ui1;

  m_oChoSrcCpnt.Clear( );
  m_oChoSrcCpnt.Append( wxT("None") );

  // Load the components into the choice box
  const wxArrayString & roasCpnts = roSim.roasGetCpntLbls( );
  for( ui1=0; ui1<roasCpnts.GetCount( ); ui1++ )
  {
    os1 = roasCpnts.Item( ui1 );
    if( os1.Length( ) <= 0 ) continue;
    switch( wxToupper( os1.GetChar( 0 ) ) )
    {
      case 'V':
      case 'I': break;
      default : continue;
    }
    m_oChoSrcCpnt.Append( os1 );
  }
  m_oChoSrcCpnt.SetStringSelection( wxT("None") );

  // Don't go any further if the analysis type doesn't match
  if( roSim.eGetAnaType( ) != eGetAnaType( ) ) return( TRUE );

  // Perform any base class load tasks
  if( ! PnlAnaBase::bLoad( roSim ) ) bRtn = FALSE;

  // Set the sweep scale
  m_oRbxScale.SetSelection( roSim.iGetSwpScale( ) );
  wxCommandEvent oEvtCmd;
  OnScale( oEvtCmd );

  return( bRtn );
}

//*****************************************************************************
// Reload information from a Simulation object.
//
// Argument List:
//   roSim - The Simulation object
//
// Return Values:
//   TRUE  - Success
//   FALSE - Failure

bool  PnlGnuCapAC::bReload( Simulation & roSim )
{
  bool      bRtn=TRUE;
  wxString  os1;
  double    df1;

  os1 = m_oChoSrcCpnt.GetStringSelection( );
  df1 = m_oPnlSrcLvl.dfGetValue( );

  if( ! bLoad( roSim ) ) bRtn = FALSE;

  if( !os1.IsEmpty( ) && os1!=wxT("None") )
  {
    m_oChoSrcCpnt.SetStringSelection( os1 );
    wxCommandEvent  oEvtCmd;
    OnSrcCpnt( oEvtCmd );
    m_oPnlSrcLvl.bSetValue( df1 );
  }

  return( bRtn );
}

//*****************************************************************************
// Save information to a Simulation object.
//
// Argument List:
//   roSim - The Simulation object
//
// Return Values:
//   TRUE  - Success
//   FALSE - Failure

bool  PnlGnuCapAC::bSave( Simulation & roSim )
{
  wxString  os1;
  size_t    szt1;

  // Execute base class save tasks
  PnlAnaBase::bSave( roSim );

  // Set the sweep scale
  if( m_oRbxScale.GetSelection( ) == (int) eSCALE_LOG )
    if( m_oPnlStep.dfGetValue( ) == 1.0 )
      SetErrMsg( wxT("Step multiplier invalid, must be non-unity.") );
  if( ! roSim.bSetSwpScale( m_oRbxScale.GetSelection( ) ) )
    SetErrMsg( wxT("Sweep scale couldn't be set.") );

  // Set the component to be used as the sweep source
  if( m_oPnlSrcLvl.dfGetValue( ) != 0.0 )
  {
    os1 = roSim.rosGetSrcCpnt( );
    szt1 = os1.Find( wxT(' '), TRUE );
    os1.insert( szt1, wxT(" GENERATOR(1) AC") );
    if( ! roSim.bSetSrcCpnt( os1 ) )
      SetErrMsg( wxT("Source component couldn't be set.") );
  }
  else SetErrMsg( wxT("Source component value of zero is not permitted.") );

  return( bIsOk( ) );
}

//*****************************************************************************
//                                                                            *
//                             Event Handlers                                 *
//                                                                            *
//*****************************************************************************
// Step scale radio box event handler.
//
// Argument List:
//   roEvtCmd - An object holding information about the event

void  PnlGnuCapAC::OnScale( wxCommandEvent & roEvtCmd )
{
  switch( m_oRbxScale.GetSelection( ) )
  {
    case eSCALE_LIN:
      m_oPnlStep.bSetName( wxT("Step Increment") );
      m_oPnlStep.bSetVarType( SpinCtrl::eVAR_FLT );
      m_oPnlStep.bSetUnitsType( ChoUnits::eUNITS_FREQ );
      m_oPnlStep.bShowUnits( TRUE );
      break;
    case eSCALE_LOG:
      m_oPnlStep.bSetName( wxT("Step Multiplier") );
      m_oPnlStep.bSetVarType( SpinCtrl::eVAR_FLT );
      m_oPnlStep.bSetParms( 1.1, 0.01, 10.0, 1.0, 10.0 );
      m_oPnlStep.bShowUnits( FALSE );
      break;
    case eSCALE_DEC:
      m_oPnlStep.bSetName( wxT("Steps / Decade") );
      m_oPnlStep.bSetVarType( SpinCtrl::eVAR_INT );
      m_oPnlStep.bSetParms( 10, 1, 10000, 1, 100 );
      m_oPnlStep.bShowUnits( FALSE );
      break;
    case eSCALE_OCT:
      m_oPnlStep.bSetName( wxT("Steps / Octave") );
      m_oPnlStep.bSetVarType( SpinCtrl::eVAR_INT );
      m_oPnlStep.bSetParms( 10, 1, 10000, 1, 100 );
      m_oPnlStep.bShowUnits( FALSE );
      break;
    default:
      break;
  }
}

//*****************************************************************************
// Source component choice box event handler.
//
// Argument List:
//   roEvtCmd - An object holding information about the event

void  PnlGnuCapAC::OnSrcCpnt( wxCommandEvent & roEvtCmd )
{
  SetSrcUType( );

  if( m_oChoSrcCpnt.GetStringSelection( ) == wxT("None") )
    m_oPnlSrcLvl.bSetValue( (double) 0.0 );
  else if( m_oPnlSrcLvl.dfGetValue( ) == 0.0 )
    m_oPnlSrcLvl.bSetValue( (double) 1.0 );
}

//*****************************************************************************
